@@ -28,10 +28,13 @@ class Sound():
 
     def _microphone_loop(self):
         while(self._running):
-            _length, chunk = self._devices.microphone_read()
-            if chunk is not None:
-                self._mumble.transmit(chunk)
-            else:
+            try:
+                _length, chunk = self._devices.microphone_read()
+                if chunk is not None:
+                    self._mumble.transmit(chunk)
+                else:
+                    sleep(0.1)
+            except TypeError:
                 sleep(0.1)
 
 
